include Behavior::Showable;
include Behavior::Buyable;

class Artwork with Showable, Buyable  {
    has creation_date;
    has creator (
        is => ro,
        # ArrayRed of Artists
        type => ArrayRef[ Object ]
    );
    has material;
    has size;
}
